@@ -161,7 +161,8 @@ module_init(GTypeModule *module)
                               HILDON_IM_KEYBOARD_DECORATOR_TYPE,
                               HILDON_IM_TYPE_PLUGIN,
                               &plugin_info);
-  conn = dbus_conn_new();
+  if(conn==NULL)
+    conn = dbus_conn_new();
 }
 
 /*
@@ -589,6 +590,7 @@ gboolean fake_key_press(guint keyval, guint state, gchar **str, gboolean *ret)
     show_candwords();
     *ret = TRUE;
   }else if(iPYInsertPoint && state == 0 && (keyval == GDK_Shift_L ||
+                              keyval == GDK_Control_L ||
                               keyval == GDK_ISO_Level3_Shift)){
       ResetPYStatus();
       show_candwords();
